@@ -38,9 +38,31 @@
 #############################################################################
 
 image.nifti <- function(x, z=1, w=1, col=gray(0:64/64),
-                        plot.type=c("multiple","single"), zlim=NULL,
+                        plane=c("axial", "coronal", "saggital"),
+                        plot.type=c("multiple", "single"), zlim=NULL,
                         xlab="", ylab="", axes=FALSE, oma=rep(0,4),
                         mar=rep(0,4), bg="black", ...) {
+  switch(plane[1],
+         "axial" = {
+           aspect <- x@pixdim[3] / x@pixdim[2]
+         },
+         "coronal" = {
+           if (length(dim(x)) == 3) {
+             x@.Data <- aperm(x, c(1,3,2))
+           } else {
+             x@.Data <- aperm(x, c(1,3,2,4))
+           }
+           aspect <- x@pixdim[4] / x@pixdim[2]
+         },
+         "saggital" = {
+           if (length(dim(x)) == 3) {
+             x@.Data <- aperm(x, c(2,3,1))
+           } else {
+             x@.Data <- aperm(x, c(2,3,1,4))
+           }
+           aspect <- x@pixdim[4] / x@pixdim[3]
+         },
+         stop(paste("Orthogonal plane", plane[1], "is not valid.")))
   ## set dimensions
   X <- nrow(x)
   Y <- ncol(x)
@@ -69,7 +91,7 @@ image.nifti <- function(x, z=1, w=1, col=gray(0:64/64),
                   length=length(col)-1),
               max(x, zlim, na.rm=TRUE))
   ## single or multiple images?
-  if (identical(plot.type[1], "multiple")) {
+  if (plot.type[1] == "multiple") {
     index <- 1:Z
   } else {
     index <- z
@@ -79,20 +101,20 @@ image.nifti <- function(x, z=1, w=1, col=gray(0:64/64),
   oldpar <- par(no.readonly=TRUE)
   par(mfrow=ceiling(rep(sqrt(lz),2)), oma=oma, mar=mar, bg=bg)
   if (is.na(Z)) { # two-dimensional matrix
-    graphics::image(1:X, 1:Y, x, col=col, breaks=breaks, axes=axes,
-                    xlab=xlab, ylab=ylab, ...)
+    graphics::image(1:X, 1:Y, x, col=col, breaks=breaks, asp=aspect,
+                    axes=axes, xlab=xlab, ylab=ylab, ...)
   } else {
     if (is.na(W)) { # three-dimensional array
       for (z in index) {
         graphics::image(1:X, 1:Y, x[,,z], col=col, breaks=breaks,
-                        axes=axes, xlab=xlab, ylab=ylab, ...)
+                        asp=aspect, axes=axes, xlab=xlab, ylab=ylab, ...)
       }
     } else { # four-dimensional array
       if (w < 1 || w > W)
         stop("volume \"w\" out of range")
       for (z in index) {
         graphics::image(1:X, 1:Y, x[,,z,w], col=col, breaks=breaks,
-                        axes=axes, xlab=xlab, ylab=ylab, ...)
+                        asp=aspect, axes=axes, xlab=xlab, ylab=ylab, ...)
       }
     }
   }
@@ -114,9 +136,33 @@ setMethod("image", signature(x="afni"),
 
 overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
                           col.y=hotmetal(), zlim.x=NULL, zlim.y=NULL,
+                          plane=c("axial", "coronal", "saggital"),
                           plot.type=c("multiple","single"),
                           xlab="", ylab="", axes=FALSE, oma=rep(0,4),
                           mar=rep(0,4), bg="black", ...) {
+  switch(plane[1],
+         "axial" = {
+           aspect <- x@pixdim[3] / x@pixdim[2]
+         },
+         "coronal" = {
+           if (length(dim(x)) == 3) {
+             x@.Data <- aperm(x, c(1,3,2))
+           } else {
+             x@.Data <- aperm(x, c(1,3,2,4))
+           }
+           y@.Data <- aperm(y, c(1,3,2))
+           aspect <- x@pixdim[4] / x@pixdim[2]
+         },
+         "saggital" = {
+           if (length(dim(x)) == 3) {
+             x@.Data <- aperm(x, c(2,3,1))
+           } else {
+             x@.Data <- aperm(x, c(2,3,1,4))
+           }
+           y@.Data <- aperm(y, c(2,3,1))
+           aspect <- x@pixdim[4] / x@pixdim[3]
+         },
+         stop(paste("Orthogonal plane", plane[1], "is not valid.")))
   ## both volumes must have the same dimension
   if (! all(dim(x)[1:3] == dim(y)[1:3])) {
     stop("dimensions of \"x\" and \"y\" must be equal")
@@ -162,7 +208,8 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
   if (is.na(W)) { # three-dimensional array
     for (z in index) {
       graphics::image(1:X, 1:Y, x[,,z], col=col.x, breaks=breaks.x,
-                      zlim=zlim.x, axes=axes, xlab=xlab, ylab=ylab, ...)
+                      zlim=zlim.x, asp=aspect, axes=axes, xlab=xlab,
+                      ylab=ylab, ...)
       graphics::image(1:X, 1:Y, y[,,z], col=col.y, zlim=zlim.y, add=TRUE)
     }
   } else { # four-dimensional array
@@ -171,7 +218,8 @@ overlay.nifti <- function(x, y, z=1, w=1, col.x=gray(0:64/64),
     }
     for (z in index) {
       graphics::image(1:X, 1:Y, x[,,z,w], col=col.x, breaks=breaks.x,
-                      zlim=zlim.x, axes=axes, xlab=xlab, ylab=ylab, ...)
+                      zlim=zlim.x, asp=aspect, axes=axes, xlab=xlab,
+                      ylab=ylab, ...)
       graphics::image(1:X, 1:Y, y[,,z], col=col.y, zlim=zlim.y, add=TRUE)
     }
   }
@@ -184,11 +232,32 @@ setMethod("overlay", signature(x="nifti", y="nifti"), overlay.nifti)
 setMethod("overlay", signature(x="anlz", y="anlz"), overlay.nifti)
 setMethod("overlay", signature(x="anlz", y="nifti"), overlay.nifti)
 setMethod("overlay", signature(x="nifti", y="anlz"), overlay.nifti)
-setMethod("overlay", signature(x="array", y="array"), overlay.nifti)
-setMethod("overlay", signature(x="array", y="nifti"), overlay.nifti)
-setMethod("overlay", signature(x="nifti", y="array"), overlay.nifti)
-setMethod("overlay", signature(x="array", y="anlz"), overlay.nifti)
-setMethod("overlay", signature(x="anlz", y="array"), overlay.nifti)
+setMethod("overlay", signature(x="array", y="array"),
+          function(x, y, ...) {
+            x <- as(x, "nifti")
+            y <- as(y, "nifti")
+            overlay.nifti(x, y, ...)
+          })
+setMethod("overlay", signature(x="array", y="nifti"),
+          function(x, y, ...) {
+            x <- as(x, "nifti")
+            overlay.nifti(x, y, ...)
+          })
+setMethod("overlay", signature(x="nifti", y="array"),
+          function(x, y, ...) {
+            y <- as(y, "nifti")
+            overlay.nifti(x, y, ...)
+          })
+setMethod("overlay", signature(x="array", y="anlz"),
+          function(x, y, ...) {
+            x <- as(x, "nifti")
+            overlay.nifti(x, y, ...)
+          })
+setMethod("overlay", signature(x="anlz", y="array"),
+          function(x, y, ...) {
+            y <- as(y, "nifti")
+            overlay.nifti(x, y, ...)
+          })
 setMethod("overlay", signature(x="afni", y="afni"),
           function(x, y, ...) {
             x <- as(x, "nifti")
@@ -210,7 +279,8 @@ orthographic.nifti <- function(x, y=NULL, xyz=NULL, w=1, col=gray(0:64/64),
                                crosshairs=TRUE, col.crosshairs="red", 
                                xlab="", ylab="", axes=FALSE,
                                oma=rep(0,4), mar=rep(0,4), bg="black",
-                               text=NULL, text.color="white", ...) {
+                               text=NULL, text.color="white",
+                               text.cex=2, ...) {
   if (! is.null(y)) {
     ## both volumes must have the same dimension
     if (! all(dim(x)[1:3] == dim(y)[1:3])) {
@@ -315,8 +385,9 @@ orthographic.nifti <- function(x, y=NULL, xyz=NULL, w=1, col=gray(0:64/64),
   }
   if (! is.null(text)) {
     ## Add user-supplied text to the "fourth" plot
-    graphics::image(1:64, 1:64, matrix(NA, 64, 64))
-    text(32, 32, text, col=text.color, cex=2)
+    graphics::image(1:64, 1:64, matrix(NA, 64, 64), xlab="", ylab="",
+                    axes=FALSE)
+    text(32, 32, text, col=text.color, cex=text.cex)
   }
   par(oldpar)
   invisible()
