@@ -233,8 +233,8 @@ setMethod("writeANALYZE", signature(aim="anlz"),
   writeBin(aim@"funused1", fid, size=4)                # 72 + 4
   writeBin(aim@"funused2", fid, size=4)                # 76 + 4
   writeBin(aim@"funused3", fid, size=4)                # 80 + 4
-  writeBin(aim@"cal_max", fid, size=4)                 # 84 + 4
-  writeBin(aim@"cal_min", fid, size=4)                 # 88 + 4
+  writeBin(as.numeric(aim@"cal_max"), fid, size=4)     # 84 + 4
+  writeBin(as.numeric(aim@"cal_min"), fid, size=4)     # 88 + 4
   writeBin(as.integer(aim@"compressed"), fid, size=4)  # 92 + 4
   writeBin(as.integer(aim@"verified"), fid, size=4)    # 96 + 4
   writeBin(as.integer(aim@"glmax"), fid, size=4)       # 100 + 4
